@@ -440,6 +440,9 @@ class BaseJAAQLController:
             for method in cur_documentation.methods:
                 methods.append(method.method)
 
+        if not self.model.is_container:
+            use_cors = True
+
         if use_cors:
             methods.append(REST__OPTIONS)
             swagger_documentation = documentation_as_lists[0]
